@@ -39,9 +39,8 @@ jump_panarea(gpointer user_data){
     START_FUNCTION;
 #endif
 #if defined OS2009
-    if ((gpointer) g_object_get_data(G_OBJECT(user_data), "length_of_jump")){
+    if ((gpointer) g_object_get_data(G_OBJECT(user_data), "length_of_jump"))
          hildon_pannable_area_scroll_to(HILDON_PANNABLE_AREA (user_data),-1, GPOINTER_TO_INT (g_object_get_data(G_OBJECT(user_data), "length_of_jump")));
-    }
     else
     if ((GtkWidget*) g_object_get_data(G_OBJECT(user_data), "selected_widget"))
         hildon_pannable_area_scroll_to_child(HILDON_PANNABLE_AREA (user_data),((GtkWidget*) g_object_get_data(G_OBJECT(user_data), "selected_widget")));
@@ -274,6 +273,7 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
                     *line_text = NULL,
                     *line = NULL,
                     *label = NULL,
+                    *previos_separator = NULL,
 #if !defined OS2009
                     *vscrollbar = NULL,
 #endif
@@ -292,12 +292,29 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
                     hi_temp,
                     low_temp;
     struct tm       tmp_time_date_struct = {0};
+    gint            font_size = 12;
+    gint            icon_size = 12;
+    gint                length_to_selected = 1;
+    gint                pre_length_to_selected = 1;
+    gint                offset = 0,
+                        offset1 = 0,
+                        offset2 = 0,
+                        offset3 = 0,
+                        offset4 = 0,
+                        offset5 = 0,
+                        offset6 = 0,
+                        whole_offset = 180,
+                        offset_default = 0;
+    GtkRequisition      requisition;
+    gboolean         hyphenation;
+
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     main_vbox = gtk_vbox_new(FALSE, 5);
 #if defined OS2009
     scrolled_window = hildon_pannable_area_new ();
+    g_object_set(G_OBJECT(scrolled_window), "mov-mode", HILDON_MOVEMENT_MODE_BOTH, NULL);
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA (scrolled_window), GTK_WIDGET (main_vbox));
 #else
     /* scrolled window */
@@ -318,6 +335,7 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
     days = (GSList*)g_hash_table_lookup(app->station_data, "forecast");
     if(days){
         while(days){
+            hyphenation = FALSE;
             day = (GHashTable*)(days->data);
             line = gtk_button_new();
             gtk_button_set_focus_on_click(GTK_BUTTON(line), FALSE);
@@ -336,10 +354,20 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
             *buffer = 0;
             snprintf(icon, sizeof(icon) - 1, "%s%s.png", app->config->icons_set_base,
                         (char*)g_hash_table_lookup(day, "day_icon"));
-            icon_buffer = gdk_pixbuf_new_from_file_at_size(icon, SMALL_ICON_SIZE,
-                                                            SMALL_ICON_SIZE, NULL);
+            switch (app->config->scale_in_popup){
+                default:
+                case 1: icon_size = SMALL_ICON_SIZE; break;
+                case 2: icon_size = MEDIUM_ICON_SIZE; break;
+                case 3: icon_size = BIG_ICON_SIZE; break;
+                case 4: icon_size = LARGE_ICON_SIZE; break;
+                case 5: icon_size = GIANT_ICON_SIZE; break;
+                case 6: icon_size = SUPER_GIANT_ICON_SIZE; break;
+            }
+            icon_buffer = gdk_pixbuf_new_from_file_at_size(icon, icon_size,
+                                                           icon_size, NULL);
+
 /*            icon_image = create_icon_widget(icon_buffer, icon, SMALL_ICON_SIZE, &app->clutter_objects_in_popup_form); */
-            icon_image = create_icon_widget(icon_buffer, icon, SMALL_ICON_SIZE, NULL);
+            icon_image = create_icon_widget(icon_buffer, icon, icon_size, NULL);
             if(icon_image){
                 gtk_box_pack_start(GTK_BOX(line_hbox), icon_image, FALSE, TRUE, 0);
                 gtk_box_pack_start(GTK_BOX(main_vbox), line, TRUE, TRUE, 0);
@@ -396,6 +424,12 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
             if(g_hash_table_lookup(day, "day_title"))
                 snprintf(tmp + strlen(tmp), sizeof(tmp) - strlen(tmp) - 1, "%s, ",
                             (char*)hash_table_find(g_hash_table_lookup(day, "day_title"), FALSE));
+            
+            if ((app->config->scale_in_popup > 3 && strlen(tmp) > 65)|| app->config->scale_in_popup == 6)
+                hyphenation = TRUE;
+            if (hyphenation)
+                snprintf(tmp + strlen(tmp), sizeof(tmp) - strlen(tmp) - 1,"\n    ");
+            
             /* wind speed */
             if(g_hash_table_lookup(day, "day_wind_speed"))
                 switch(app->config->wind_units){
@@ -430,6 +464,10 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
             if(g_hash_table_lookup(day, "night_title"))
                 snprintf(tmp + strlen(tmp), sizeof(tmp) - strlen(tmp) - 1, "%s, ",
                             (char*)hash_table_find(g_hash_table_lookup(day, "night_title"), FALSE));
+
+            if (hyphenation)
+                snprintf(tmp + strlen(tmp), sizeof(tmp) - strlen(tmp) - 1,"\n    ");
+ 
             /* wind speed */
             if(g_hash_table_lookup(day, "night_wind_speed"))
                 switch(app->config->wind_units){
@@ -459,15 +497,78 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
             line_text = gtk_label_new(NULL);
             gtk_label_set_justify(GTK_LABEL(line_text), GTK_JUSTIFY_FILL);
             gtk_label_set_markup(GTK_LABEL(line_text), buffer);
-            set_font(line_text, NULL, 12);
+
+	        switch (app->config->scale_in_popup){
+                case 2: font_size = 14; break;     
+                case 3: font_size = 16; break;
+                case 4: font_size = 18; break;
+                case 5: font_size = 21; break;
+	            case 6: font_size = 24; break;
+                case 1:  	      
+                default: font_size = 12; break;
+            }
+ 
+            set_font(line_text, NULL, font_size);
+
             gtk_box_pack_start(GTK_BOX(line_hbox), line_text, FALSE, TRUE, 10);
 
-            if(day_number == i)
-                g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)separator);
+            /* Calculate ofset for jump */
+            gtk_widget_size_request (line_text, &requisition);
+            pre_length_to_selected = length_to_selected;
+            length_to_selected = length_to_selected + requisition.height;
+            gtk_widget_size_request (separator, &requisition);
+            length_to_selected = length_to_selected + requisition.height;
+
+            if(day_number == i + 1){
+                switch (app->config->scale_in_popup){
+                    case 2:  
+                            offset2 = 70; 
+                            offset_default = 43; 
+                            break;     
+                    case 3:  
+                            offset2 = 90; 
+                            offset_default = 55; 
+                            break;
+                    case 4:  
+                            offset2 = 115; 
+                            offset_default = 73; 
+                            break;
+                    case 5:  
+                            offset2 = 190; 
+                            offset_default = 105; 
+                            break;
+                    case 6: offset2 = 420; 
+                            offset_default = 210;
+                            break;
+                    case 1:  	      
+                    default:
+                            offset2 = 60; 
+                            offset_default = 35; 
+                             break;
+
+                }
+                previos_separator = separator;
+                switch (i){
+                    case 0: break;
+    //                case 1: if (current_widget && current) 
+    //                            pre_length_to_selected = 0; 
+    //                        break;
+                    case 2: offset = offset2;break;
+                    default: offset = i*offset_default;break;
+                }
+     
+               g_object_set_data(G_OBJECT(scrolled_window), "length_of_jump", 
+                       GINT_TO_POINTER(pre_length_to_selected+offset + whole_offset));
+        }
+        
+        //    if(day_number == i)
+        //        g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)separator);
             /* next day */
             days = g_slist_next(days);
             i++;
         }
+//	if(day_number == i)
+//                g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)separator);
     }
     else{ /* no weather data */
         gtk_box_pack_start(GTK_BOX(main_vbox),
@@ -509,6 +610,13 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
     gint                length_to_selected = 1;
     gint                pre_length_to_selected = 1;
     gint                offset = 0;
+    gint                offset1 = 0;
+    gint                offset2 = 0;
+    gint                offset3 = 0;
+    gint                offset4 = 0;
+    gint                offset5 = 0;
+    gint                offset_default = 0;
+    gint                whole_offset = 0;
 
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -517,6 +625,7 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
     /* scrolled window */
 #if defined OS2009
     scrolled_window = hildon_pannable_area_new();
+    g_object_set(G_OBJECT(scrolled_window), "mov-mode", HILDON_MOVEMENT_MODE_BOTH, NULL);
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(scrolled_window), GTK_WIDGET(main_vbox));
 #else
     scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -548,7 +657,7 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
             gtk_button_set_relief(GTK_BUTTON(line), GTK_RELIEF_NONE);
             g_signal_connect(G_OBJECT(line), "clicked",
                                 G_CALLBACK(show_detailes_of_current_day_button_handler),
-                                 GINT_TO_POINTER(i));
+                                 GINT_TO_POINTER(i+1-app->config->separate));
             g_object_set_data(G_OBJECT(line), "scrolled_window", (gpointer)scrolled_window);
             g_object_set_data(G_OBJECT(line), "vbox", (gpointer)vbox);
             current_widget = create_current_tab(current);
@@ -574,11 +683,11 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
             if (i == 0)
                 g_signal_connect(G_OBJECT(line), "clicked",
                                             G_CALLBACK(show_detailes_of_current_day_button_handler),
-                                                                             GINT_TO_POINTER(i));
+                                                                             GINT_TO_POINTER(i+1));
             else
                 g_signal_connect(G_OBJECT(line), "clicked",
                                 G_CALLBACK(show_collapsed_day_button_handler),
-                                 GINT_TO_POINTER(i));
+                                 GINT_TO_POINTER(i+1));
 
         g_object_set_data(G_OBJECT(line), "scrolled_window", (gpointer)scrolled_window);
         g_object_set_data(G_OBJECT(line), "vbox", (gpointer)vbox);
@@ -597,29 +706,91 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
         if(day_number == i && !(i == 0 && current_widget && current))
             previos_separator = separator;
         /* If activited day and not current weather */
-        if(day_number + 1 == i && !(i == 0 && current_widget && current)){
+        if(day_number  == i && !(i == 0 && current_widget && current)){
             g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)previos_separator);
+            switch (app->config->scale_in_popup){
+                case 2:  
+                        offset1 = 110; 
+                        offset2 = 190; 
+                        offset3 = 90; 
+                        offset4 = 85; 
+                        offset5 = 80; 
+                        offset_default = 77;   
+                        whole_offset = 140;
+                        break;     
+                case 3:  
+                        offset1 = 140; 
+                        offset2 = 240; 
+                        offset3 = 110; 
+                        offset4 = 115; 
+                        offset5 = 110; 
+                        offset_default = 110; 
+                        whole_offset = 140;
+                        break;
+                case 4:  
+                        offset1 = 175; 
+                        offset2 = 300; 
+                        offset3 = 140; 
+                        offset4 = 130; 
+                        offset5 = 134; 
+                        offset_default = 130; 
+                        whole_offset = 140;
+                        break;
+                case 5:  
+                        offset1 = 170; 
+                        offset2 = 300; 
+                        offset3 = 140; 
+                        offset4 = 140; 
+                        offset5 = 140; 
+                        offset_default = 140; 
+                        whole_offset = 140;
+                        break;
+                case 6: 
+                        offset1 = 120;
+                        offset2 = 230;
+                        offset3 = 110; 
+                        offset4 = 110; 
+                        offset5 = 120; 
+                        offset_default = 110;
+                        whole_offset = 140;
+                        break;
+                case 1:  	      
+                default:
+                        offset1 = 251; 
+                        offset2 = 310; 
+                        offset3 = 120; 
+                        offset4 = 105; 
+                        offset5 = 95; 
+                        offset_default = 87; 
+                        break;
+            }
+
             switch (i){
-                case 0: break;
+                case 0: whole_offset = 0;break;
                 case 1: if (current_widget && current) 
                             pre_length_to_selected = 0; 
+                            offset = offset1;
                         break;
-                case 2: offset = 45;break;
-                case 3: offset = i*44;break;
-                case 4: offset = i*45;break;
-                case 5: offset = i*45;break;
-                default: offset = i*51;break;
+                case 2: offset = offset2;break;
+                case 3: offset = i*offset3;break;
+                case 4: offset = i*offset4;break;
+                case 5: offset = i*offset5;break;
+                default: offset = i*offset_default;break;
             }
-            g_object_set_data(G_OBJECT(scrolled_window), "length_of_jump", GINT_TO_POINTER(pre_length_to_selected+offset));
+            g_object_set_data(G_OBJECT(scrolled_window), "length_of_jump", GINT_TO_POINTER(pre_length_to_selected+offset + whole_offset));
         }
-        if(day_number == Max_count_weather_day - 1 && i == Max_count_weather_day - 1){
+        if (day_number == Max_count_weather_day - 1 && i == Max_count_weather_day - 1){
             g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)line);
         }
         tmp = g_slist_next(tmp);
         i++;
         g_free(day_name);
     }
-    
+    if(day_number + 1 == i){
+        g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)separator);
+    }
+
+   
     gtk_widget_show_all(main_vbox);
     gtk_widget_show_all(scrolled_window);
 #ifdef HILDONANIMATION 
@@ -700,6 +871,8 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
     gboolean        flag = FALSE,
                     new_day = FALSE;
     struct tm       *gmt;
+    gint            font_size = 12;
+    gint            icon_size = SMALL_ICON_SIZE;
 
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -708,6 +881,7 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
     /* scrolled window */
 #if defined OS2009
     scrolled_window = hildon_pannable_area_new ();
+    g_object_set(G_OBJECT(scrolled_window), "mov-mode", HILDON_MOVEMENT_MODE_BOTH, NULL);
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA (scrolled_window), GTK_WIDGET (main_vbox));
 #else
     scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -788,13 +962,21 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
                 update_icons_set_base(NULL);
                 sprintf(buffer,"%s%s.png", app->config->icons_set_base,
                            (char*)g_hash_table_lookup(hour_weather, "hour_icon"));
-                icon = gdk_pixbuf_new_from_file_at_size(buffer, SMALL_ICON_SIZE,
-                                                      SMALL_ICON_SIZE, NULL);
-/*                icon_image = create_icon_widget(icon, buffer, SMALL_ICON_SIZE,
-                            &app->clutter_objects_in_popup_form);
-*/
-                icon_image = create_icon_widget(icon, buffer, SMALL_ICON_SIZE,
-                                             NULL);
+                switch (app->config->scale_in_popup){
+                    default:
+                    case 1: icon_size = SMALL_ICON_SIZE; break;
+                    case 2: icon_size = MEDIUM_ICON_SIZE; break;
+                    case 3: icon_size = BIG_ICON_SIZE; break;
+                    case 4: icon_size = LARGE_ICON_SIZE; break;
+                    case 5: icon_size = GIANT_ICON_SIZE; break;
+                    case 6: icon_size = SUPER_GIANT_ICON_SIZE; break;
+                }
+                icon = gdk_pixbuf_new_from_file_at_size(buffer, icon_size,
+                                                           icon_size, NULL);
+
+/*            icon_image = create_icon_widget(icon_buffer, icon, SMALL_ICON_SIZE, &app->clutter_objects_in_popup_form); */
+                icon_image = create_icon_widget(icon, buffer, icon_size, NULL);
+
                 if(icon_image){
                     gtk_box_pack_start(GTK_BOX(line_hbox), icon_image, FALSE, TRUE, 0);
                     gtk_box_pack_start(GTK_BOX(main_vbox), line, TRUE, TRUE, 0);
@@ -838,6 +1020,9 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
                        (char*)hash_table_find(g_hash_table_lookup(hour_weather, "hour_title"), 
                         FALSE));
 
+                if (app->config->scale_in_popup > 4)
+                        sprintf(tmp + strlen(tmp), "\n");
+
                 /* wind speed */
                 if(g_hash_table_lookup(hour_weather, "hour_wind_speed"))
                     switch(app->config->wind_units){
@@ -878,7 +1063,18 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
                 line_text = gtk_label_new(NULL);
                 gtk_label_set_justify(GTK_LABEL(line_text), GTK_JUSTIFY_FILL);
                 gtk_label_set_markup(GTK_LABEL(line_text), buffer);
-                set_font(line_text, NULL, 12);
+
+                switch (app->config->scale_in_popup){
+                    case 2: font_size = 14; break;     
+                    case 3: font_size = 16; break;
+                    case 4: font_size = 18; break;
+                    case 5: font_size = 21; break;
+                    case 6: font_size = 24; break;
+                    case 1:  	      
+                    default: font_size = 12; break;
+                }
+                set_font(line_text, NULL, font_size);
+
                 gtk_box_pack_start(GTK_BOX(line_hbox), line_text, FALSE, TRUE, 10);
                 gtk_box_pack_start(GTK_BOX(main_vbox), gtk_hseparator_new(), FALSE, TRUE, 0);
                 hours_weather = g_slist_next(hours_weather);
